@@ -19,6 +19,8 @@ from cocoa.cli.arg_types.data_types import (
     Paths,
     Pattern,
     RawFile,
+    YamlFile,
+    YamlFileWithDefault,
 )
 from cocoa.cli.arg_types.data_types.reduce_pattern_type import reduce_pattern_type
 from cocoa.cli.arg_types.operators import Operator
@@ -27,6 +29,55 @@ T = TypeVar("T")
 
 
 class PositionalArg(Generic[T]):
+    complex_types: dict[
+        AssertPath
+        | AssertSet
+        | Context
+        | Env
+        | ImportInstance
+        | ImportType
+        | JsonData
+        | JsonData
+        | Operator
+        | Paths
+        | Pattern
+        | RawFile
+        | YamlFile
+        | YamlFileWithDefault,
+        Callable[
+            [str, type[Any]],
+            AssertPath
+            | AssertSet
+            | Context
+            | Env
+            | ImportInstance
+            | ImportType
+            | JsonData
+            | JsonData
+            | Operator
+            | Paths
+            | Pattern
+            | RawFile
+            | YamlFile
+            | YamlFileWithDefault,
+        ],
+    ] = {
+        AssertPath: lambda _, __: AssertPath(),
+        AssertSet: lambda name, subtype: AssertSet(name, subtype),
+        Context: lambda _, __: Context(),
+        Env: lambda envar, subtype: Env(envar, subtype),
+        ImportInstance: lambda _, subtype: ImportInstance(subtype),
+        ImportType: lambda _, subtype: ImportType(subtype),
+        JsonFile: lambda _, subtype: JsonFile(subtype),
+        JsonData: lambda _, subtype: JsonData(subtype),
+        Operator: lambda name, subtype: Operator(name, subtype),
+        Paths: lambda _, subtype: Paths(subtype),
+        Pattern: lambda _, subtype: Pattern(subtype),
+        RawFile: lambda _, subtype: RawFile(subtype),
+        YamlFile: lambda _, __: YamlFile(),
+        YamlFileWithDefault: lambda _, __: YamlFileWithDefault(),
+    }
+    
     def __init__(
         self,
         name: str,
@@ -44,54 +95,12 @@ class PositionalArg(Generic[T]):
         self.is_envar: bool = False
 
         args = get_args(data_type)
-        self._complex_types: dict[
-            AssertPath
-            | AssertSet
-            | Context
-            | Env
-            | ImportInstance
-            | ImportType
-            | JsonData
-            | JsonData
-            | Operator
-            | Paths
-            | Pattern
-            | RawFile,
-            Callable[
-                [str, type[Any]],
-                AssertPath
-                | AssertSet
-                | Context
-                | Env
-                | ImportInstance
-                | ImportType
-                | JsonData
-                | JsonData
-                | Operator
-                | Paths
-                | Pattern
-                | RawFile,
-            ],
-        ] = {
-            AssertPath: lambda _, __: AssertPath(),
-            AssertSet: lambda name, subtype: AssertSet(name, subtype),
-            Context: lambda _, __: Context(),
-            Env: lambda envar, subtype: Env(envar, subtype),
-            ImportInstance: lambda _, subtype: ImportInstance(subtype),
-            ImportType: lambda _, subtype: ImportType(subtype),
-            JsonFile: lambda _, subtype: JsonFile(subtype),
-            JsonData: lambda _, subtype: JsonData(subtype),
-            Operator: lambda name, subtype: Operator(name, subtype),
-            Paths: lambda _, subtype: Paths(subtype),
-            Pattern: lambda _, subtype: Pattern(subtype),
-            RawFile: lambda _, subtype: RawFile(subtype),
-        }
 
         self._is_complex_type = (
             get_origin(
                 data_type,
             )
-            in self._complex_types.keys()
+            in self.complex_types.keys()
         )
 
         if len(args) > 0 and self._is_complex_type is False:
@@ -148,9 +157,9 @@ class PositionalArg(Generic[T]):
         for subtype in self._value_type:
             try:
                 if (
-                    complex_type_factory := self._complex_types.get(get_origin(subtype))
+                    complex_type_factory := self.complex_types.get(get_origin(subtype))
                 ) or (
-                    complex_type_factory := self._complex_types.get(subtype)
+                    complex_type_factory := self.complex_types.get(subtype)
                 ):
                     complex_type = complex_type_factory(self.name, subtype)
 
@@ -159,7 +168,11 @@ class PositionalArg(Generic[T]):
                 elif subtype is bytes:
                     return bytes(value, encoding="utf-8")
 
-                return subtype(value)
+                elif callable(subtype):
+                    return subtype(value)
+                
+                else:
+                    return value
 
             except Exception as e:
                 parse_error = e
