@@ -14,6 +14,8 @@ from cocoa.cli.arg_types.data_types import (
     Paths,
     Pattern,
     RawFile,
+    YamlFile,
+    YamlFileWithDefault,
 )
 
 T = TypeVarTuple("T")
@@ -48,7 +50,9 @@ class Chain(Generic[*T]):
             | JsonData
             | JsonData
             | Pattern
-            | RawFile,
+            | RawFile
+            | YamlFile
+            | YamlFileWithDefault,
             Callable[
                 [str, type[Any]],
                 AssertPath
@@ -59,7 +63,9 @@ class Chain(Generic[*T]):
                 | JsonData
                 | JsonData
                 | Pattern
-                | RawFile,
+                | RawFile
+                | YamlFile
+                | YamlFileWithDefault
             ],
         ] = {
             AssertPath: lambda _, __: AssertPath(),
@@ -72,6 +78,8 @@ class Chain(Generic[*T]):
             Paths: lambda _, subtype: Paths(subtype),
             Pattern: lambda _, subtype: Pattern(subtype),
             RawFile: lambda _, subtype: RawFile(subtype),
+            YamlFile: lambda _, __: YamlFile(),
+            YamlFileWithDefault: lambda _, __: YamlFileWithDefault(),
         }
 
         self._loop = asyncio.get_event_loop()
