@@ -14,6 +14,7 @@ from .arg_types import (
     KeywordArgType,
     
 )
+from .arg_types.data_types.check_if_multiarg import check_if_multiarg
 from .help_message import create_help_string, CLIStyle
 
 
@@ -72,14 +73,10 @@ def inspect_wrapped(
     position_index: int = 0
 
     for arg_name, arg_attrs in call_args.parameters.items():
-
-        is_multiarg = arg_attrs.annotation in [
-            list,
-            set,
-        ] or get_origin(arg_attrs.annotation) in [
-            list,
-            set,
-        ]
+        is_multiarg = check_if_multiarg(arg_attrs.annotation, [
+            *KeywordArg.complex_types,
+            *PositionalArg.complex_types
+        ])
 
         if (
             arg_attrs.default == inspect._empty
@@ -126,11 +123,11 @@ def inspect_wrapped(
 
             required = no_default and none_not_preset
 
-
+            full_flag = "-".join(arg_name.split("_"))
             keyword_arg = KeywordArg(
                 arg_name,
                 arg_attrs.annotation,
-                short_name=shortnames.get(arg_name),
+                short_name=shortnames.get(full_flag),
                 required=required,
                 default=arg_default,
                 arg_type=arg_type,
